@@ -1,6 +1,12 @@
-import os
-import argparse
+from __future__ import print_function
 
+try:
+    raw_input
+except NameError:
+    raw_input = input
+
+import argparse
+import pip
 from pkg_resources import working_set, get_distribution
 
 
@@ -11,12 +17,13 @@ def autoremove(name, yes=False):
     print("Uninstalling:")
     show_tree(dist, dead)
     if yes or confirm("Proceed (y/N)?"):
-        map(remove_dist, dead)
+        for d in dead:
+            remove_dist(d)
 
 
 def show_tree(dist, dead, indent=0):
     prefix = ' ' * indent * 4
-    print prefix,
+    print(prefix, end=' ')
     show_dist(dist)
     for req in requires(dist):
         if req in dead:
@@ -53,7 +60,10 @@ def show_dist(dist):
 
 
 def remove_dist(dist):
-    os.system('pip uninstall -y %s' % dist.project_name)
+    pip.main(['uninstall', '-y', dist.project_name])
+    # Avoid duplicate output caused by pip.logger.consumers being configured
+    # over and over again
+    pip.logger.consumers = []
 
 
 def get_graph():
